@@ -345,7 +345,7 @@ class GerritChange(BaseModel):
         """
         return self.gerrit.post(self.endpoint + "/revert_submission")
 
-    def submit(self, input_):
+    def submit(self, input_=None):
         """
         Submits  a change.
         Submitting a change also removes all users from the attention set.
@@ -367,8 +367,13 @@ class GerritChange(BaseModel):
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#submit-input
         :return:
         """
-        return self.gerrit.post(self.endpoint + "/submit",
-                                json=input_, headers=self.gerrit.default_headers)
+        endpoint = self.endpoint + "/submit"
+        if input_ is None:
+            result = self.gerrit.post(endpoint)
+        else:
+            result = self.gerrit.post(endpoint,
+                                    json=input_, headers=self.gerrit.default_headers)
+        return result
 
     def list_submitted_together_changes(self):
         """
