@@ -2,6 +2,7 @@
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
 from gerrit.groups.group import GerritGroup
+from gerrit.utils.common import params_creator
 from packaging.version import parse
 
 
@@ -27,22 +28,8 @@ class GerritGroups(object):
                      number of groups from the beginning of the list
         :return:
         """
-        pattern_types = {"match": "m", "regex": "r"}
-
-        p, v = None, None
-        if pattern_dispatcher is not None and pattern_dispatcher:
-            for item in pattern_types:
-                if item in pattern_dispatcher:
-                    p, v = pattern_types[item], pattern_dispatcher[item]
-                    break
-            else:
-                raise ValueError("Pattern types can be either 'match' or 'regex'.")
-
-        params = {
-            k: v
-            for k, v in (("o", options), ("n", limit), ("S", skip), (p, v))
-            if v is not None
-        }
+        params = params_creator((("o", options), ("n", limit), ("S", skip)),
+                                {"match": "m", "regex": "r"}, pattern_dispatcher)
 
         return self.gerrit.get(self.endpoint, params=params)
 
